@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 """
-unittest测试增强库.更友好、更灵活的编写、管理与运行测试，生成更加美观的独立单文件HTML报告。内置参数化测试数据存取方案，省去设计的烦恼，节省更多的时间，从而更快的投入到编写用例阶段
+基于unittest开发的测试框架.更友好、更灵活的编写、管理与运行测试，生成更加美观的独立单文件HTML报告。内置参数化测试数据存取方案，省去设计的烦恼，节省更多的时间，从而更快的投入到编写用例阶段
 
  * 使用装饰器Test来标记测试方法更加灵活
  * 支持命名测试方法且不与方法的doc string（文档字符串）冲突
@@ -9,6 +9,7 @@ unittest测试增强库.更友好、更灵活的编写、管理与运行测试
  * 支持设置测试方法的执行优先级
  * 支持参数化功能
  * 支持数据驱动测试
+ * 支持设置用例依赖
  * 内置参数化数据存取方案
  * 更加美观的HTML报告
 
